complete -W "
list \
todo \
upgrade \
mapfile \
init \
history \
diff \
--help \
--version \
--root \
--incoming \
--activity \
--product \
--institute \
--model \
--experiment \
--frequency \
--realm \
--profile \
--detect-product \
--shelve-dir \
--p-cmip5-config \
--move-cmd \
" -f drs_tool

complete -W "
--help \
--incude \
--exclude \
--copy \
--dry-run \
--loglevel \
" -f translate_cmip3

complete -W "
--help \
--catalog \
" -f drs_checkthredds
